// Toggle dark mode

const body = document.querySelector("body");

function toggleDarkMode() {
  if (body.classList.contains("dark-mode")) {
    body.classList.remove("dark-mode");
    body.classList.add("light-mode");
    localStorage.setItem("theme", "light-mode");
  } else {
    body.classList.remove("light-mode");
    body.classList.add("dark-mode");
    localStorage.setItem("theme", "dark-mode");
  }
}

if (localStorage.getItem("theme") === "dark-mode") {
  body.classList.add("dark-mode");
}

if (localStorage.getItem("theme") === "light-mode") {
  body.classList.add("light-mode");
}

// sidebar active menu
activeSideMenu();
function activeSideMenu() {
  var current = $(location).attr("href");
  $(".sidebar-links .nav-link").each(function () {
    var $this = $(this);
    if (current.indexOf($this.attr("href")) !== -1) {
      $this.addClass("active");
      var $submenu = $(this).closest(".submenu");
      var $submenuId = $submenu.attr("id");
      var isActive = $submenu.hasClass("show");
      if (!isActive) {
        $('a[href="#' + $submenuId + '"]').trigger("click");
        $(this)
          .parent()
          .parent()
          .parent()
          .children()
          .siblings(".nav-link")
          .addClass("active");
      }
    } else {
      $this.removeClass("active");
    }
  });
}

$('.sidebar-links .nav-item a:not([data-toggle="collapse"])').click(
  function () {
    activeSideMenu();
  }
);

// Shrink button event listener
const shrinkBtn = document.querySelector(".shrink-btn");
shrinkBtn.addEventListener("click", () => {
  document.body.classList.toggle("shrink");
  setTimeout(moveActiveTab, 400);
  shrinkBtn.classList.add("hovered");
  setTimeout(() => {
    shrinkBtn.classList.remove("hovered");
  }, 500);
});

// Show tooltip
function showTooltip() {
  let tooltip = this.parentNode.lastElementChild;
  let spans = tooltip.children;
  let tooltipIndex = this.dataset.tooltip;
  tooltip.style.top = `${(100 / (spans.length * 2)) * (tooltipIndex * 2 + 1)}%`;
}

// Toggle submenu
function toggleSubmenu() {
  submenu.classList.toggle("show");
  arrowIcon.classList.toggle("expanded");
}

// Checkboxes
$(document).ready(function () {
  // Check or uncheck all checkboxes when the table header checkbox is clicked
  $("#checkAll").click(function () {
    $("tbody :checkbox").prop("checked", $(this).prop("checked"));
  });

  // Uncheck the table header checkbox if any checkbox in the table body is unchecked
  $("tbody :checkbox").click(function () {
    if (!$(this).prop("checked")) {
      $("#checkAll").prop("checked", false);
    }
  });
  const body = document.querySelector("body");
  body.classList.add("light-mode");
  if (body.classList.contains("dark-mode")) {
    body.classList.remove("light-mode");
  }

  if (
    window.location.href.indexOf("index") > -1 ||
    window.location.href.indexOf("widget") > -1
  ) {
    body.classList.add("widget-body");
    body.classList.add("homepage-body");
  } else {
    body.classList.add("other-page-body");
  }
  if (window.location.href.indexOf("widget") > -1) {
    body.classList.add("widget-body");
    body.classList.remove("homepage-body");
  } else {
    body.classList.add("other-page-body");
  }
});

// Pagination
$(document).ready(function () {
  var rowsPerPage = 5;
  var currentPage = 1;
  var totalRows = $("tbody tr").length;
  var totalPages = Math.ceil(totalRows / rowsPerPage);

  updatePagination();

  $(".btn-prev").click(function () {
    if (currentPage > 1) {
      currentPage--;
      updatePagination();
    }
  });

  $(".btn-next").click(function () {
    if (currentPage < totalPages) {
      currentPage++;
      updatePagination();
    }
  });

  function updatePagination() {
    var startIndex = (currentPage - 1) * rowsPerPage;
    var endIndex = startIndex + rowsPerPage;

    // $("tbody tr").hide();
    $("tbody tr").slice(startIndex, endIndex).show();

    $(".pagination-info").text("Page " + currentPage + " of " + totalPages);
    $(".btn-prev").prop("disabled", currentPage === 1);
    $(".btn-next").prop(
      "disabled",
      currentPage === totalPages || totalRows === 0
    );
  }
});

// Add project modal
$(document).ready(function () {
  // Add Project button click event handler
  $("#addProjectBtn").click(function () {
    // Clear form fields
    $("#addProjectForm")[0].reset();
    // Show the modal
    $("#addProjectModal").modal("show");
  });

  // Save Project button click event handler
  $("#saveProjectBtn").click(function () {
    // Get the values from the form fields
    var projectName = $("#projectName").val();
    var projectCategory = $("#projectCategory").val();
    var projectProgress = $("#projectProgress").val();
    var projectLastUpdate = $("#projectLastUpdate").val();
    var projectStatus = $("#projectStatus").val();
    var projectDeadline = $("#projectDeadline").val();

    // Create a new table row with the project data
    var newRow = $("<tr>");

    // Add checkbox column
    var checkboxColumn = $("<td>")
      .attr("scope", "row")
      .append(
        $("<input>")
          .addClass("form-check-input")
          .attr("type", "checkbox")
          .val("")
      );
    newRow.append(checkboxColumn);

    // Add project name column
    var projectNameColumn = $("<td>")
      .addClass("table-project-name")
      .append(
        $("<img>")
          .addClass("pe-2")
          .attr("src", "./assets/table-img/project.png")
          .attr("alt", "alternate-text")
      )
      .append(projectName);
    newRow.append(projectNameColumn);

    // Add project category column
    var projectCategoryColumn = $("<td>").text(projectCategory);
    newRow.append(projectCategoryColumn);

    // Add project progress column
    var progressContainer = $("<div>").addClass("progress");
    var progressBar = $("<div>")
      .addClass("progress-bar")
      .attr("role", "progressbar")
      .css("width", projectProgress + "%")
      .attr("aria-valuenow", projectProgress)
      .attr("aria-valuemin", "0")
      .attr("aria-valuemax", "100")
      .text(projectProgress + "%");
    progressContainer.append(progressBar);
    var progressColumn = $("<td>").append(progressContainer);
    newRow.append(progressColumn);

    // Add last update column
    var lastUpdateColumn = $("<td>").text(projectLastUpdate);
    newRow.append(lastUpdateColumn);

    // Add status column
    var statusDot = $("<span>").addClass("active-dot me-2");
    var statusText = $("<span>").text(projectStatus);
    var statusColumn = $("<td>").append(
      $("<div>")
        .addClass("table-status d-flex")
        .append(statusDot)
        .append(statusText)
    );
    if (projectStatus === "inactive") {
      statusColumn.addClass("inactive");
    }
    newRow.append(statusColumn);

    // Add deadline column
    var deadlineColumn = $("<td>").text(projectDeadline);
    newRow.append(deadlineColumn);

    // Add delete column with trash icon
    var deleteColumn = $("<td>")
      .addClass("text-center")
      .html('<i class="bx bx-trash delete-icon cursor-pointer"></i>');
    newRow.append(deleteColumn);

    // Append the new row to the table body
    $("table tbody").append(newRow);

    // Hide the modal
    $("#addProjectModal").modal("hide");
  });
});

// Delete table row
$(document).on("click", ".bx-trash", function () {
  // Get the parent table row
  var row = $(this).closest("tr");

  // Remove the row from the table
  row.remove();
});
// ----------------------------------

// Get all tab links and tab content sections
const tabLinks = document.querySelectorAll(".sidebar-links .tabs");
const tabContent = document.querySelectorAll(".section-tab-content");

// Add click event listeners to each tab link
tabLinks.forEach((linkss) => {
  linkss.addEventListener("click", (e) => {
    e.preventDefault();
    const tabId = e.target.getAttribute("data-tab");

    // Remove 'active' class from all tab links and tab content sections
    tabLinks.forEach((linkss) => linkss.classList.remove("active"));
    tabContent.forEach((content) => content.classList.remove("active"));

    // Add 'active' class to the clicked tab link
    e.target.classList.add("active");

    // Load content from separate HTML file and insert it into the corresponding tab content section
    fetchContent(tabId);
  });
});

// Function to fetch content from separate HTML file
function fetchContent(tabId) {
  fetch(`${tabId}.html`)
    .then((response) => response.text())
    .then((data) => {
      const tabContent = document.getElementById(tabId);
      tabContent.innerHTML = data;
      tabContent.classList.add("active");
    })
    .catch((error) => {
      console.log("Error fetching content:", error);
    });
}

// ===========Timeline javascript=======================

jQuery(document).ready(function ($) {
  var timelines = $(".cd-horizontal-timeline"),
    eventsMinDistance = 60;

  timelines.length > 0 && initTimeline(timelines);

  function initTimeline(timelines) {
    timelines.each(function () {
      var timeline = $(this),
        timelineComponents = {};
      //cache timeline componentabts
      timelineComponents["timelineWrapper"] = timeline.find(".events-wrapper");
      timelineComponents["eventsWrapper"] =
        timelineComponents["timelineWrapper"].children(".events");
      timelineComponents["fillingLine"] =
        timelineComponents["eventsWrapper"].children(".filling-line");
      timelineComponents["timelineEvents"] =
        timelineComponents["eventsWrapper"].find("a");
      timelineComponents["timelineDates"] = parseDate(
        timelineComponents["timelineEvents"]
      );
      timelineComponents["eventsMinLapse"] = minLapse(
        timelineComponents["timelineDates"]
      );
      timelineComponents["timelineNavigation"] = timeline.find(
        ".cd-timeline-navigation"
      );
      timelineComponents["eventsContent"] =
        timeline.children(".events-content");

      //assign a left postion to the single events along the timeline
      setDatePosition(timelineComponents, eventsMinDistance);
      //assign a width to the timeline
      var timelineTotWidth = setTimelineWidth(
        timelineComponents,
        eventsMinDistance
      );
      //the timeline has been initialize - show it
      timeline.addClass("loaded");

      //detect click on the next arrow
      timelineComponents["timelineNavigation"].on(
        "click",
        ".next",
        function (event) {
          event.preventDefault();
          updateSlide(timelineComponents, timelineTotWidth, "next");
        }
      );
      //detect click on the prev arrow
      timelineComponents["timelineNavigation"].on(
        "click",
        ".prev",
        function (event) {
          event.preventDefault();
          updateSlide(timelineComponents, timelineTotWidth, "prev");
        }
      );
      //detect click on the a single event - show new event content
      timelineComponents["eventsWrapper"].on("click", "a", function (event) {
        event.preventDefault();
        timelineComponents["timelineEvents"].removeClass("selected");
        $(this).addClass("selected");
        updateOlderEvents($(this));
        updateFilling(
          $(this),
          timelineComponents["fillingLine"],
          timelineTotWidth
        );
        updateVisibleContent($(this), timelineComponents["eventsContent"]);
      });

      //on swipe, show next/prev event content
      timelineComponents["eventsContent"].on("swipeleft", function () {
        var mq = checkMQ();
        mq == "mobile" &&
          showNewContent(timelineComponents, timelineTotWidth, "next");
      });
      timelineComponents["eventsContent"].on("swiperight", function () {
        var mq = checkMQ();
        mq == "mobile" &&
          showNewContent(timelineComponents, timelineTotWidth, "prev");
      });

      //keyboard navigation
      $(document).keyup(function (event) {
        if (event.which == "37" && elementInViewport(timeline.get(0))) {
          showNewContent(timelineComponents, timelineTotWidth, "prev");
        } else if (event.which == "39" && elementInViewport(timeline.get(0))) {
          showNewContent(timelineComponents, timelineTotWidth, "next");
        }
      });
    });
  }

  function updateSlide(timelineComponents, timelineTotWidth, string) {
    //retrieve translateX value of timelineComponents['eventsWrapper']
    var translateValue = getTranslateValue(timelineComponents["eventsWrapper"]),
      wrapperWidth = Number(
        timelineComponents["timelineWrapper"].css("width").replace("px", "")
      );
    //translate the timeline to the left('next')/right('prev')
    string == "next"
      ? translateTimeline(
          timelineComponents,
          translateValue - wrapperWidth + eventsMinDistance,
          wrapperWidth - timelineTotWidth
        )
      : translateTimeline(
          timelineComponents,
          translateValue + wrapperWidth - eventsMinDistance
        );
  }

  function showNewContent(timelineComponents, timelineTotWidth, string) {
    //go from one event to the next/previous one
    var visibleContent = timelineComponents["eventsContent"].find(".selected"),
      newContent =
        string == "next" ? visibleContent.next() : visibleContent.prev();

    if (newContent.length > 0) {
      //if there's a next/prev event - show it
      var selectedDate = timelineComponents["eventsWrapper"].find(".selected"),
        newEvent =
          string == "next"
            ? selectedDate.parent("li").next("li").children("a")
            : selectedDate.parent("li").prev("li").children("a");

      updateFilling(
        newEvent,
        timelineComponents["fillingLine"],
        timelineTotWidth
      );
      updateVisibleContent(newEvent, timelineComponents["eventsContent"]);
      newEvent.addClass("selected");
      selectedDate.removeClass("selected");
      updateOlderEvents(newEvent);
      updateTimelinePosition(string, newEvent, timelineComponents);
    }
  }

  function updateTimelinePosition(string, event, timelineComponents) {
    //translate timeline to the left/right according to the position of the selected event
    var eventStyle = window.getComputedStyle(event.get(0), null),
      eventLeft = Number(eventStyle.getPropertyValue("left").replace("px", "")),
      timelineWidth = Number(
        timelineComponents["timelineWrapper"].css("width").replace("px", "")
      ),
      timelineTotWidth = Number(
        timelineComponents["eventsWrapper"].css("width").replace("px", "")
      );
    var timelineTranslate = getTranslateValue(
      timelineComponents["eventsWrapper"]
    );

    if (
      (string == "next" && eventLeft > timelineWidth - timelineTranslate) ||
      (string == "prev" && eventLeft < -timelineTranslate)
    ) {
      translateTimeline(
        timelineComponents,
        -eventLeft + timelineWidth / 2,
        timelineWidth - timelineTotWidth
      );
    }
  }

  function translateTimeline(timelineComponents, value, totWidth) {
    var eventsWrapper = timelineComponents["eventsWrapper"].get(0);
    value = value > 0 ? 0 : value; //only negative translate value
    value =
      !(typeof totWidth === "undefined") && value < totWidth ? totWidth : value; //do not translate more than timeline width
    setTransformValue(eventsWrapper, "translateX", value + "px");
    //update navigation arrows visibility
    value == 0
      ? timelineComponents["timelineNavigation"]
          .find(".prev")
          .addClass("inactive")
      : timelineComponents["timelineNavigation"]
          .find(".prev")
          .removeClass("inactive");
    value == totWidth
      ? timelineComponents["timelineNavigation"]
          .find(".next")
          .addClass("inactive")
      : timelineComponents["timelineNavigation"]
          .find(".next")
          .removeClass("inactive");
  }

  function updateFilling(selectedEvent, filling, totWidth) {
    //change .filling-line length according to the selected event
    var eventStyle = window.getComputedStyle(selectedEvent.get(0), null),
      eventLeft = eventStyle.getPropertyValue("left"),
      eventWidth = eventStyle.getPropertyValue("width");
    eventLeft =
      Number(eventLeft.replace("px", "")) +
      Number(eventWidth.replace("px", "")) / 2;
    var scaleValue = eventLeft / totWidth;
    setTransformValue(filling.get(0), "scaleX", scaleValue);
  }

  function setDatePosition(timelineComponents, min) {
    for (i = 0; i < timelineComponents["timelineDates"].length; i++) {
      var distance = daydiff(
          timelineComponents["timelineDates"][0],
          timelineComponents["timelineDates"][i]
        ),
        distanceNorm =
          Math.round(distance / timelineComponents["eventsMinLapse"]) + 2;
      timelineComponents["timelineEvents"]
        .eq(i)
        .css("left", distanceNorm * min + "px");
    }
  }

  function setTimelineWidth(timelineComponents, width) {
    var timeSpan = daydiff(
        timelineComponents["timelineDates"][0],
        timelineComponents["timelineDates"][
          timelineComponents["timelineDates"].length - 1
        ]
      ),
      timeSpanNorm = timeSpan / timelineComponents["eventsMinLapse"],
      timeSpanNorm = Math.round(timeSpanNorm) + 4,
      totalWidth = timeSpanNorm * width;
    timelineComponents["eventsWrapper"].css("width", totalWidth + "px");
    updateFilling(
      timelineComponents["eventsWrapper"].find("a.selected"),
      timelineComponents["fillingLine"],
      totalWidth
    );
    updateTimelinePosition(
      "next",
      timelineComponents["eventsWrapper"].find("a.selected"),
      timelineComponents
    );

    return totalWidth;
  }

  function updateVisibleContent(event, eventsContent) {
    var eventDate = event.data("date"),
      visibleContent = eventsContent.find(".selected"),
      selectedContent = eventsContent.find('[data-date="' + eventDate + '"]'),
      selectedContentHeight = selectedContent.height();

    if (selectedContent.index() > visibleContent.index()) {
      var classEnetering = "selected enter-right",
        classLeaving = "leave-left";
    } else {
      var classEnetering = "selected enter-left",
        classLeaving = "leave-right";
    }

    selectedContent.attr("class", classEnetering);
    visibleContent
      .attr("class", classLeaving)
      .one(
        "webkitAnimationEnd oanimationend msAnimationEnd animationend",
        function () {
          visibleContent.removeClass("leave-right leave-left");
          selectedContent.removeClass("enter-left enter-right");
        }
      );
    eventsContent.css("height", selectedContentHeight + "px");
  }

  function updateOlderEvents(event) {
    event
      .parent("li")
      .prevAll("li")
      .children("a")
      .addClass("older-event")
      .end()
      .end()
      .nextAll("li")
      .children("a")
      .removeClass("older-event");
  }

  function getTranslateValue(timeline) {
    var timelineStyle = window.getComputedStyle(timeline.get(0), null),
      timelineTranslate =
        timelineStyle.getPropertyValue("-webkit-transform") ||
        timelineStyle.getPropertyValue("-moz-transform") ||
        timelineStyle.getPropertyValue("-ms-transform") ||
        timelineStyle.getPropertyValue("-o-transform") ||
        timelineStyle.getPropertyValue("transform");

    if (timelineTranslate.indexOf("(") >= 0) {
      var timelineTranslate = timelineTranslate.split("(")[1];
      timelineTranslate = timelineTranslate.split(")")[0];
      timelineTranslate = timelineTranslate.split(",");
      var translateValue = timelineTranslate[4];
    } else {
      var translateValue = 0;
    }

    return Number(translateValue);
  }

  function setTransformValue(element, property, value) {
    element.style["-webkit-transform"] = property + "(" + value + ")";
    element.style["-moz-transform"] = property + "(" + value + ")";
    element.style["-ms-transform"] = property + "(" + value + ")";
    element.style["-o-transform"] = property + "(" + value + ")";
    element.style["transform"] = property + "(" + value + ")";
  }

  //based on http://stackoverflow.com/questions/542938/how-do-i-get-the-number-of-days-between-two-dates-in-javascript
  function parseDate(events) {
    var dateArrays = [];
    events.each(function () {
      var singleDate = $(this),
        dateComp = singleDate.data("date").split("T");
      if (dateComp.length > 1) {
        //both DD/MM/YEAR and time are provided
        var dayComp = dateComp[0].split("/"),
          timeComp = dateComp[1].split(":");
      } else if (dateComp[0].indexOf(":") >= 0) {
        //only time is provide
        var dayComp = ["2000", "0", "0"],
          timeComp = dateComp[0].split(":");
      } else {
        //only DD/MM/YEAR
        var dayComp = dateComp[0].split("/"),
          timeComp = ["0", "0"];
      }
      var newDate = new Date(
        dayComp[2],
        dayComp[1] - 1,
        dayComp[0],
        timeComp[0],
        timeComp[1]
      );
      dateArrays.push(newDate);
    });
    return dateArrays;
  }

  function daydiff(first, second) {
    return Math.round(second - first);
  }

  function minLapse(dates) {
    //determine the minimum distance among events
    var dateDistances = [];
    for (i = 1; i < dates.length; i++) {
      var distance = daydiff(dates[i - 1], dates[i]);
      dateDistances.push(distance);
    }
    return Math.min.apply(null, dateDistances);
  }

  /*
  How to tell if a DOM element is visible in the current viewport?
  http://stackoverflow.com/questions/123999/how-to-tell-if-a-dom-element-is-visible-in-the-current-viewport
*/
  function elementInViewport(el) {
    var top = el.offsetTop;
    var left = el.offsetLeft;
    var width = el.offsetWidth;
    var height = el.offsetHeight;

    while (el.offsetParent) {
      el = el.offsetParent;
      top += el.offsetTop;
      left += el.offsetLeft;
    }

    return (
      top < window.pageYOffset + window.innerHeight &&
      left < window.pageXOffset + window.innerWidth &&
      top + height > window.pageYOffset &&
      left + width > window.pageXOffset
    );
  }

  function checkMQ() {
    //check if mobile or desktop device
    return window
      .getComputedStyle(
        document.querySelector(".cd-horizontal-timeline"),
        "::before"
      )
      .getPropertyValue("content")
      .replace(/'/g, "")
      .replace(/"/g, "");
  }
});

	// Full screen
	$(document).on("click", ".fullscreen-button", function toggleFullScreen() {
		$('html').addClass('fullscreen');
		if ((document.fullScreenElement !== undefined && document.fullScreenElement === null) || (document.msFullscreenElement !== undefined && document.msFullscreenElement === null) || (document.mozFullScreen !== undefined && !document.mozFullScreen) || (document.webkitIsFullScreen !== undefined && !document.webkitIsFullScreen)) {
			if (document.documentElement.requestFullScreen) {
				document.documentElement.requestFullScreen();
			} else if (document.documentElement.mozRequestFullScreen) {
				document.documentElement.mozRequestFullScreen();
			} else if (document.documentElement.webkitRequestFullScreen) {
				document.documentElement.webkitRequestFullScreen(Element.ALLOW_KEYBOARD_INPUT);
			} else if (document.documentElement.msRequestFullscreen) {
				document.documentElement.msRequestFullscreen();
			}
		} else {
			$('html').removeClass('fullscreen');
			if (document.cancelFullScreen) {
				document.cancelFullScreen();
			} else if (document.mozCancelFullScreen) {
				document.mozCancelFullScreen();
			} else if (document.webkitCancelFullScreen) {
				document.webkitCancelFullScreen();
			} else if (document.msExitFullscreen) {
				document.msExitFullscreen();
			}
		}
	});